Authors
=======

`Anatoly Bubenkov <bubenkoff@gmail.com>`_
    original idea and implementation

These people have contributed to `pytest-faker`, in alphabetical order:

* `Oleg Pidsadnyi <oleg.pidsadnyi@gmail.com>`_
